==> jumbo-pbx-0.1.tar.gz: jumbo-pbx-0.1/pbx/utenti/views.py <==
# -*- coding: utf-8 -*-
'''
Created on 5/ago/2011

@author: simone cittadini
'''
import sys, datetime

from django.http import HttpResponse, HttpResponseRedirect
from django.template.context import RequestContext
from django.shortcuts import get_object_or_404, render_to_response
from django.views.decorators.csrf import csrf_exempt
from django.db.models import Q
from django.views.generic.create_update import update_object

from pbx.switch.models import Account, SERVERURL, Device
from pbx.utenti.models import UtentePBX, EnabledCookie, PersonalPhonebookEntry,\
    BlacklistEntry
from django.template.loader import render_to_string

from forms import SetCallerCookie, PersonalPhonebookEntryForm


FROM_EMAIL = 'voip@primasgr.it' #TODO da local settings

def retrieve__utenti_monitorati(request, utente_pbx_id=None):
    """
    Torna una lista con lo stato degli account monitorati dall'utente che fa la
    request, o dall'utente di cui si passa l'id
    """
    if utente_pbx_id:
        u = get_object_or_404(UtentePBX, pk=utente_pbx_id)
    else:
        raise NotImplementedError
    
    return render_to_response('utenti/retrieve__utenti_monitorati.html',
                              locals())

def create__personalphonebookentry(request, utente_pbx_id=None):
    """
    Form per la creazione di una entry nel personal phonebook
    """
    if utente_pbx_id:
        u = get_object_or_404(UtentePBX, pk=utente_pbx_id)
    else:
        raise NotImplementedError #prendere l'utentepbx dallo user della request
    if request.method == 'POST':
        form = PersonalPhonebookEntryForm(request.POST)
        if form.is_valid():
            PersonalPhonebookEntry.objects.create(utentepbx=u,
                                                  numero=form.cleaned_data['numero'],
                                                  nome=form.cleaned_data['nome'])
            return HttpResponseRedirect("/")
    else:
        form = PersonalPhonebookEntryForm()
    return render_to_response('utenti/create__personalphonebookentry.html',
                              locals(), RequestContext(request))
    
def update__personalphonebookentry(request, id):
    """
    Modifica un campo del personal phonebook
    """
    e = get_object_or_404(PersonalPhonebookEntry, pk=id)
    return update_object(request, form_class=PersonalPhonebookEntryForm,
                         object_id=id, post_save_redirect="/")
    
def delete__personalphonebookentry(request, id):
    """
    Elimina un campo del personal phonebook
    """
    e = get_object_or_404(PersonalPhonebookEntry, pk=id)
    e.delete()
    return HttpResponseRedirect("/")
            
def retrieve__personalphonebook(request, utente_pbx_id):
    """
    Torna una lista delle entry nel personal phonebook dell'utente ad argomento
    """
    u = get_object_or_404(UtentePBX, pk=utente_pbx_id)
    qs = PersonalPhonebookEntry.objects.filter(utentepbx=u)
    return render_to_response('utenti/retrieve__personalphonebook.html',
                              locals())
    
def retrieve__utenti_monitorati_by_name(request, utente_pbx_nome):
    """
    Torna una lista con lo stato degli account monitorati dall'utente di cui
    si passa il nome
    """
    u = get_object_or_404(UtentePBX, nome=utente_pbx_nome)
    return retrieve__utenti_monitorati(request, u.pk)
    
@csrf_exempt
def retrieve__utenti(request, reset=False):
    """
    Torna una lista di tutti gli utenti #TODO vedere se regge il controllo dello stato
    """
    accounts = Account.objects.all()
    # se l'utente ha postato il suo cli dobbiamo settare il cookie
    if request.method == 'POST': 
        form =  SetCallerCookie(request.POST)
        if form.is_valid():
            accounts = accounts.exclude(
                                    name__exact=form.cleaned_data['caller_cli'])
            just_set = True
            r = render_to_response('utenti/retrieve_utenti.html', locals())
            r.set_cookie(key='JUMBO_PBX_CALLER',
                         value=form.cleaned_data['caller_cli'],
                         max_age=80000)
            ec, created = EnabledCookie.objects.get_or_create(value=form.cleaned_data['caller_cli'])
            ec.enabled = False
            ec.save()
            return r
    # se il cookie non è settato ci serve il form per settarlo
    if not request.COOKIES.has_key('JUMBO_PBX_CALLER'):
        if reset:
            r = HttpResponseRedirect("/utenti/retrieve__utenti/")
            r.delete_cookie(key='JUMBO_PBX_CALLER')
            return r
        setcallercookie_form = SetCallerCookie()
        return render_to_response('utenti/retrieve_utenti.html', locals())
    else:
        name = request.COOKIES['JUMBO_PBX_CALLER']
        accounts = accounts.exclude(
                                name__exact=request.COOKIES['JUMBO_PBX_CALLER'])
        r = render_to_response('utenti/retrieve_utenti.html', locals())
        # se reset=True voglio resettare il cookie
        if reset:
            r = HttpResponseRedirect("/utenti/retrieve__utenti/")
            r.delete_cookie(key='JUMBO_PBX_CALLER')
        return r

@csrf_exempt
def retrieve__utenti_reset(request):
    try:
        ec = EnabledCookie.objects.get(value=request.COOKIES['JUMBO_PBX_CALLER'])
        ec.delete()
        del request.COOKIES['JUMBO_PBX_CALLER']
    except Exception, e:
        print >> sys.stderr, "errore in cancellazione abilitazione cookie: %s" % str(e)
    return retrieve__utenti(request, reset=True)

@csrf_exempt
def curl_enable_cookie(request, cli):
    try:
        ec = EnabledCookie.objects.get(value=cli)
        td = datetime.datetime.now() - ec.timestamp
        if td.seconds < 30:
            ec.enabled = True
            ec.save()
        return HttpResponse("OK")
    except Exception, e:
        print >> sys.stderr, "errore in abilitazione cookie: %s" % str(e)
        return HttpResponse("KO")

    
def curl_postnoanswer(request, cli, exten):
    """
    Chiamata da asterisk con curl se l'hangup è avvenuto per nonaswer.
    """
    try:
        print >> sys.stderr, "CURL_POSTNOANSWER %s %s"  % (cli, exten)
        caller_account = None
        # se la chiamata veniva da fuori l'extension ha aggiunto uno 0
        if cli[0:1] == '0':
            cli = cli[1:]
            esterno = True
            print >> sys.stderr, "cli esterno"
        else:
            esterno = False
            print >> sys.stderr, "cli interno"
            # se la chiamata veniva da dentro voglio anche il nome utente
            try:
                caller_account = Account.objects.get(name=cli)
                print >> sys.stderr, "trovato caller account"
            except Exception ,e:
                print >> sys.stderr, "eccezione %s" % str(e)
        a = Account.objects.get(name=exten)
        u = a.utentepbx
        ctx_dict = {'caller_number' : cli, 'caller_account' : caller_account, 'esterno' : esterno}
        subject = render_to_string('utenti/mail/noanswer_email_subject.txt',
                                   ctx_dict)
        # Email subject *must not* contain newlines
        subject = ''.join(subject.splitlines())
        
        message = render_to_string('utenti/mail/noanswer_email.txt',
                                   ctx_dict)
        try:
            u.get_user().email_user(subject, message, from_email=FROM_EMAIL)
        except:
            print >> sys.stderr, "non ho scritto a : %s\n%s\n%s" % \
                (u.get_user().email, subject, message)
            return HttpResponse("KO_no_mail_to_%s" % u.get_user().email)
    except Exception, e:
        return HttpResponse("KO_%s" % str(e))
    return HttpResponse("OK")

def curl_postnoanswer_nosrc(request, exten):
    return HttpResponse("OK")
    
def curl_postnoanswer_nodst(request, cli):
    return HttpResponse("OK")

def cisco_services_personalphonebook(request, device_id, first_index):
    serverurl = SERVERURL
    id = device_id
    device = Device.objects.get(pk=id)
    account = device.account
    utente = account.utentepbx
    entries = PersonalPhonebookEntry.objects.all()
    xml = render_to_string('switch/cisco/services/personalphonebook.xml', locals())
    return HttpResponse(xml, mimetype="text/xml")

def cisco_services_personalphonebooksearch(request, device_id):
    serverurl = SERVERURL
    id = device_id
    xml = render_to_string('switch/cisco/services/personalphonebooksearch.xml', locals())
    return HttpResponse(xml, mimetype="text/xml")

def cisco_services_personalphonebookqs(request, device_id):
    serverurl = SERVERURL
    id = device_id
    device = Device.objects.get(pk=id)
    account = device.account
    utente = account.utentepbx
    search = request.GET['search']
    entries = PersonalPhonebookEntry.objects.filter(Q(nome__icontains=search) | 
                                      Q(numero__icontains=search))
    xml = render_to_string('switch/cisco/services/personalphonebookqs.xml', locals())
    return HttpResponse(xml, mimetype="text/xml")

def curl_check_blacklist(request, cli, verso='BOTH'):
    try:
        b = BlacklistEntry.objects.get(numero=cli)
        if b.verso == 'BOTH' or b.verso == verso:
            return HttpResponse('OK')
        return HttpResponse('KO')
    except BlacklistEntry.DoesNotExist:
        return HttpResponse('KO')

==> jumbo-pbx-0.1.1.tar.gz: jumbo-pbx-0.1.1/pbx/utenti/views.py <==
# -*- coding: utf-8 -*-
'''
Created on 5/ago/2011

@author: simone cittadini
'''
import sys, datetime

from django.http import HttpResponse, HttpResponseRedirect
from django.template.context import RequestContext
from django.shortcuts import get_object_or_404, render_to_response
from django.views.decorators.csrf import csrf_exempt
from django.db.models import Q
from django.views.generic.create_update import update_object
from django.core.urlresolvers import reverse

from pbx.switch.models import Account, SERVERURL, Device
from pbx.utenti.models import UtentePBX, EnabledCookie, PersonalPhonebookEntry,\
    BlacklistEntry, SpeedDialEntry
from django.template.loader import render_to_string

from forms import SetCallerCookie, PersonalPhonebookEntryForm


FROM_EMAIL = 'voip@primasgr.it' #TODO da local settings

def retrieve__utenti_monitorati(request, utente_pbx_id=None):
    """
    Torna una lista con lo stato degli account monitorati dall'utente che fa la
    request, o dall'utente di cui si passa l'id
    """
    if utente_pbx_id:
        u = get_object_or_404(UtentePBX, pk=utente_pbx_id)
    else:
        raise NotImplementedError
    
    return render_to_response('utenti/retrieve__utenti_monitorati.html',
                              locals())

def create__personalphonebookentry(request, utente_pbx_id=None):
    """
    Form per la creazione di una entry nel personal phonebook
    """
    if utente_pbx_id:
        u = get_object_or_404(UtentePBX, pk=utente_pbx_id)
    else:
        raise NotImplementedError #prendere l'utentepbx dallo user della request
    if request.method == 'POST':
        form = PersonalPhonebookEntryForm(request.POST)
        if form.is_valid():
            PersonalPhonebookEntry.objects.create(utentepbx=u,
                                                  numero=form.cleaned_data['numero'],
                                                  nome=form.cleaned_data['nome'])
            return HttpResponseRedirect(reverse("admin:pbx_utenti_retrieve_personalphonebook", args=[utente_pbx_id]))
    else:
        form = PersonalPhonebookEntryForm()
    return render_to_response('utenti/create__personalphonebookentry.html',
                              locals(), RequestContext(request))
    
def update__personalphonebookentry(request, id):
    """
    Modifica un campo del personal phonebook
    """
    e = get_object_or_404(PersonalPhonebookEntry, pk=id)
    utentepbx_id = e.utentepbx.pk
    return update_object(request, form_class=PersonalPhonebookEntryForm,
                         object_id=id, 
                         template_name='utenti/create__personalphonebookentry.html',
                         post_save_redirect=reverse("admin:pbx_utenti_retrieve_personalphonebook", args=[utentepbx_id]))
    
def delete__personalphonebookentry(request, id):
    """
    Elimina un campo del personal phonebook
    """
    e = get_object_or_404(PersonalPhonebookEntry, pk=id)
    utentepbx_id = e.utentepbx.pk
    e.delete()
    return HttpResponseRedirect(reverse("admin:pbx_utenti_retrieve_personalphonebook", args=[utentepbx_id]))
            
def retrieve__personalphonebook(request, utente_pbx_id):
    """
    Torna una lista delle entry nel personal phonebook dell'utente ad argomento
    """
    u = get_object_or_404(UtentePBX, pk=utente_pbx_id)
    qs = PersonalPhonebookEntry.objects.filter(utentepbx=u)
    return render_to_response('utenti/retrieve__personalphonebook.html',
                              locals())
    
def retrieve__utenti_monitorati_by_name(request, utente_pbx_nome):
    """
    Torna una lista con lo stato degli account monitorati dall'utente di cui
    si passa il nome
    """
    u = get_object_or_404(UtentePBX, nome=utente_pbx_nome)
    return retrieve__utenti_monitorati(request, u.pk)

def create_personalphonebook(request):
    u = PbxProfiles.objects.get(user=request.user).get_profile(UtentePBX)
    if request.method == 'POST':
        form = PersonalPhonebookEntryForm(request.POST, request=request)
        if form.is_valid():
            form.save()
            return HttpResponseRedirect(reverse('retrieve_personalphonebook'))
    else:
        form = PersonalPhonebookEntryForm()
    return render_to_response('utenti/personalphonebookentry_form.html',
                              locals(), RequestContext(request))

def retrieve_personalphonebook(request):
    u = PbxProfiles.objects.get(user=request.user).get_profile(UtentePBX)
    qs = PersonalPhonebookEntry.objects.filter(utentepbx__exact=u)
    return object_list(request, qs)

def update_personalphonebook(request, id):
    u = PbxProfiles.objects.get(user=request.user).get_profile(UtentePBX)
    e = PersonalPhonebookEntry.objects.get(pk=id)
    if request.method == 'POST':
        form = PersonalPhonebookEntryForm(request.POST, instance=e, request=request)
        if form.is_valid():
            e.numero = form.cleaned_data['numero']
            e.nome = form.cleaned_data['nome']
            e.save()
            return HttpResponseRedirect(reverse('retrieve_personalphonebook'))
    else:
        form = PersonalPhonebookEntryForm(instance=e)
    return render_to_response('utenti/personalphonebookentry_form.html',
                              locals(), RequestContext(request))

def delete_personalphonebook(request, id):
    u = PbxProfiles.objects.get(user=request.user).get_profile(UtentePBX)
    
    return delete_object(request, model=PersonalPhonebookEntry, object_id=id,
                         post_delete_redirect=reverse('retrieve_personalphonebook'))

    
@csrf_exempt
def retrieve__utenti(request, reset=False):
    """
    Torna una lista di tutti gli utenti #TODO vedere se regge il controllo dello stato
    """
    accounts = Account.objects.all()
    # se l'utente ha postato il suo cli dobbiamo settare il cookie
    if request.method == 'POST': 
        form =  SetCallerCookie(request.POST)
        if form.is_valid():
            accounts = accounts.exclude(
                                    name__exact=form.cleaned_data['caller_cli'])
            just_set = True
            r = render_to_response('utenti/retrieve_utenti.html', locals())
            r.set_cookie(key='JUMBO_PBX_CALLER',
                         value=form.cleaned_data['caller_cli'],
                         max_age=80000)
            ec, created = EnabledCookie.objects.get_or_create(value=form.cleaned_data['caller_cli'])
            ec.enabled = False
            ec.save()
            return r
    # se il cookie non è settato ci serve il form per settarlo
    if not request.COOKIES.has_key('JUMBO_PBX_CALLER'):
        if reset:
            r = HttpResponseRedirect("/utenti/retrieve__utenti/")
            r.delete_cookie(key='JUMBO_PBX_CALLER')
            return r
        setcallercookie_form = SetCallerCookie()
        return render_to_response('utenti/retrieve_utenti.html', locals())
    else:
        name = request.COOKIES['JUMBO_PBX_CALLER']
        accounts = accounts.exclude(
                                name__exact=request.COOKIES['JUMBO_PBX_CALLER'])
        r = render_to_response('utenti/retrieve_utenti.html', locals())
        # se reset=True voglio resettare il cookie
        if reset:
            r = HttpResponseRedirect("/utenti/retrieve__utenti/")
            r.delete_cookie(key='JUMBO_PBX_CALLER')
        return r

@csrf_exempt
def retrieve__utenti_reset(request):
    try:
        ec = EnabledCookie.objects.get(value=request.COOKIES['JUMBO_PBX_CALLER'])
        ec.delete()
        del request.COOKIES['JUMBO_PBX_CALLER']
    except Exception, e:
        print >> sys.stderr, "errore in cancellazione abilitazione cookie: %s" % str(e)
    return retrieve__utenti(request, reset=True)

@csrf_exempt
def curl_enable_cookie(request, cli):
    try:
        ec = EnabledCookie.objects.get(value=cli)
        td = datetime.datetime.now() - ec.timestamp
        if td.seconds < 30:
            ec.enabled = True
            ec.save()
        return HttpResponse("OK")
    except Exception, e:
        print >> sys.stderr, "errore in abilitazione cookie: %s" % str(e)
        return HttpResponse("KO")

    
def curl_postnoanswer(request, cli, exten):
    """
    Chiamata da asterisk con curl se l'hangup è avvenuto per nonaswer.
    """
    try:
        print >> sys.stderr, "CURL_POSTNOANSWER %s %s"  % (cli, exten)
        caller_account = None
        # se la chiamata veniva da fuori l'extension ha aggiunto uno 0
        if cli[0:1] == '0':
            cli = cli[1:]
            esterno = True
            print >> sys.stderr, "cli esterno"
        else:
            esterno = False
            print >> sys.stderr, "cli interno"
            # se la chiamata veniva da dentro voglio anche il nome utente
            try:
                caller_account = Account.objects.get(name=cli)
                print >> sys.stderr, "trovato caller account"
            except Exception ,e:
                print >> sys.stderr, "eccezione %s" % str(e)
#        a = Account.objects.get(name=exten)
#        u = a.utentepbx
#        ctx_dict = {'caller_number' : cli, 'caller_account' : caller_account, 'esterno' : esterno}
#        subject = render_to_string('utenti/mail/noanswer_email_subject.txt',
#                                   ctx_dict)
#        # Email subject *must not* contain newlines
#        subject = ''.join(subject.splitlines())
#        
#        message = render_to_string('utenti/mail/noanswer_email.txt',
#                                   ctx_dict)
#        try:
#            u.get_user().email_user(subject, message, from_email=FROM_EMAIL)
#        except:
#            print >> sys.stderr, "non ho scritto a : %s\n%s\n%s" % \
#                (u.get_user().email, subject, message)
#            return HttpResponse("KO_no_mail_to_%s" % u.get_user().email)
    except Exception, e:
        return HttpResponse("KO_%s" % str(e))
    return HttpResponse("OK")

def curl_postnoanswer_nosrc(request, exten):
    return HttpResponse("OK")
    
def curl_postnoanswer_nodst(request, cli):
    return HttpResponse("OK")

def curl_postnoanswer_nosrcdst(request):
    return HttpResponse("OK")

def cisco_services_personalphonebook(request, device_id, first_index):
    serverurl = SERVERURL
    id = device_id
    device = Device.objects.get(pk=id)
    account = device.account
    utente = account.utentepbx
    entries = PersonalPhonebookEntry.objects.all()
    xml = render_to_string('switch/cisco/services/personalphonebook.xml', locals())
    return HttpResponse(xml, mimetype="text/xml")

def cisco_services_personalphonebooksearch(request, device_id):
    serverurl = SERVERURL
    id = device_id
    xml = render_to_string('switch/cisco/services/personalphonebooksearch.xml', locals())
    return HttpResponse(xml, mimetype="text/xml")

def cisco_services_personalphonebookqs(request, device_id):
    serverurl = SERVERURL
    id = device_id
    device = Device.objects.get(pk=id)
    account = device.account
    utente = account.utentepbx
    search = request.GET['search']
    entries = PersonalPhonebookEntry.objects.filter(Q(nome__icontains=search) | 
                                      Q(numero__icontains=search))
    xml = render_to_string('switch/cisco/services/personalphonebookqs.xml', locals())
    return HttpResponse(xml, mimetype="text/xml")

def curl_check_blacklist(request, cli, verso='BOTH'):
    try:
        b = BlacklistEntry.objects.get(numero=cli)
        if b.verso == 'BOTH' or b.verso == verso:
            return HttpResponse('OK')
        return HttpResponse('KO')
    except BlacklistEntry.DoesNotExist:
        return HttpResponse('KO')
    
def get_speedial(request, num):
    try:
        s = SpeedDialEntry.objects.get(numero=num)
        if Account.objects.filter(name__exact=s.destinazione).count() > 0:
            return HttpResponse('int%s' % s.destinazione)
        else:
            return HttpResponse('ext%s' % s.destinazione)
    except Exception, e:
        return HttpResponse('KO_%s' % str(e))
